Datum class

Constructors

Datum({String? availabilityid, String? availabilityname, List? country, dynamic exclusionlist, List? devicetypelist, String? pricemodel, String? quality, dynamic regionlist, int? licenseduration, String? accesstype, dynamic description, dynamic adcueid})
Datum.fromJson(String data)
dart:convert
factory
Datum.fromMap(Map<String, dynamic> data)
factory

Properties

accesstype ↔ String?
getter/setter pair
adcueid ↔ dynamic
getter/setter pair
availabilityid ↔ String?
getter/setter pair
availabilityname ↔ String?
getter/setter pair
country ↔ List?
getter/setter pair
description ↔ dynamic
getter/setter pair
devicetypelist ↔ List?
getter/setter pair
exclusionlist ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
licenseduration ↔ int?
getter/setter pair
pricemodel ↔ String?
getter/setter pair
quality ↔ String?
getter/setter pair
regionlist ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
dart:convert
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited