ContentModel class

Constructors

ContentModel({int? totalcount, List<Datum>? data})
ContentModel.fromJson(String data)
dart:convert
factory
ContentModel.fromMap(Map<String, dynamic> data)
factory

Properties

data ↔ List<Datum>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalcount ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
dart:convert
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

content → const String
course → const String
series → const String
tvshow → const String